@@ -24,3 +24,10 @@ def get_em_cookie():
     stock_account_info = mongodb_util.find_query_data('stock_account_info', {"type": "em_cookie", })
     em_cookie = list(stock_account_info['cookie'])[0]
     return em_cookie
+
+
+@lru_cache(maxsize=None)
+def get_xue_qiu_cookie():
+    stock_account_info = mongodb_util.find_query_data('stock_account_info', {"type": "xue_qiu", })
+    cookie = list(stock_account_info['cookie'])[0]
+    return cookie
